@@ -1,10 +1,20 @@
-package CPAN::Reporter::PrereqCheck;
+#
+# This file is part of CPAN-Reporter
+#
+# This software is Copyright (c) 2006 by David Golden.
+#
+# This is free software, licensed under:
+#
+#   The Apache License, Version 2.0, January 2004
+#
 use strict;
-use vars qw/$VERSION/;
-$VERSION = '1.1803';
-$VERSION = eval $VERSION; ## no critic
+package CPAN::Reporter::PrereqCheck;
+BEGIN {
+  $CPAN::Reporter::PrereqCheck::VERSION = '1.1900';
+}
+# ABSTRACT: Modulino for prerequisite tests
 
-use ExtUtils::MakeMaker;
+use ExtUtils::MakeMaker 6.36;
 use File::Spec;
 use CPAN::Version;
 
@@ -113,78 +123,75 @@ sub _run {
 
 1;
 
-__END__
 
-#--------------------------------------------------------------------------#
-# pod documentation
-#--------------------------------------------------------------------------#
 
-=begin wikidoc
+=pod
 
-= NAME
+=head1 NAME
 
 CPAN::Reporter::PrereqCheck - Modulino for prerequisite tests
 
-= VERSION
+=head1 VERSION
 
-This documentation describes version %%VERSION%%.
+version 1.1900
 
-= SYNOPSIS
+=head1 SYNOPSIS
 
- require CPAN::Reporter::PrereqCheck;
- my $prereq_check = $INC{'CPAN/Reporter/PrereqCheck.pm'};
- my $result = qx/$perl $prereq_check < $prereq_file/;
+  require CPAN::Reporter::PrereqCheck;
+  my $prereq_check = $INC{'CPAN/Reporter/PrereqCheck.pm'};
+  my $result = qx/$perl $prereq_check < $prereq_file/;
 
-= DESCRIPTION
+=head1 DESCRIPTION
 
 This modulino determines whether a list of prerequisite modules are
 available and, if so, their version number.  It is designed to be run
 as a script in order to provide this information from the perspective of
-a subprocess, just like CPAN::Reporter's invocation of {perl Makefile.PL}
+a subprocess, just like CPAN::Reporter's invocation of C<<< perl Makefile.PL >>>
 and so on.
 
 It reads a module name and prerequisite string pair from each line of input
 and prints out the module name, 0 or 1 depending on whether the prerequisite
 is satisifed, and the installed module version.  If the module is not
-available, it will print "n/a" for the version.  If the module is available
+available, it will print "nE<sol>a" for the version.  If the module is available
 but can't be loaded, it will print "broken" for the version.  Modules
 without a version will be treated as being of version "0".
 
 No user serviceable parts are inside.  This modulino is packaged for
 internal use by CPAN::Reporter.
 
-= BUGS
+=head1 BUGS
 
 Please report any bugs or feature using the CPAN Request Tracker.
 Bugs can be submitted through the web interface at
-[http://rt.cpan.org/Dist/Display.html?Queue=CPAN-Reporter]
+L<http://rt.cpan.org/Dist/Display.html?Queue=CPAN-Reporter>
 
 When submitting a bug or request, please include a test-file or a patch to an
 existing test-file that illustrates the bug or desired feature.
 
-= SEE ALSO
+=head1 SEE ALSO
 
-* [CPAN::Reporter] -- main documentation
+=over
 
-= AUTHOR
+=item *
 
-David A. Golden (DAGOLDEN)
+L<CPAN::Reporter> -- main documentation
 
-= COPYRIGHT AND LICENSE
+=back
 
-Copyright (c) 2006, 2007 by David A. Golden
+=head1 AUTHOR
 
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-[http://www.apache.org/licenses/LICENSE-2.0]
+David Golden <dagolden@cpan.org>
 
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
+=head1 COPYRIGHT AND LICENSE
 
-=end wikidoc
+This software is Copyright (c) 2006 by David Golden.
+
+This is free software, licensed under:
+
+  The Apache License, Version 2.0, January 2004
 
 =cut
+
+
+__END__
+
